<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="438"/>
        <source>Add files to the current archive</source>
        <translation>Amiesta ficheros al archivu actual</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="443"/>
        <source>Use password</source>
        <translation>Usar una contraseña</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>El ficheru orixinal de %1 nun esiste, compruébalo y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 nun esiste nel discu, compruébalo y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <source>You do not have permission to compress %1</source>
        <translation>Nun tienes permisu pa comprimir %1</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>Anovando'l comentariu…</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="81"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="122"/>
        <source>Please add files</source>
        <translation>Amiesta ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="122"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D'acuerdu</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="146"/>
        <source>New Archive</source>
        <translation>Archivu nuevu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="207"/>
        <source>Advanced Options</source>
        <translation>Opciones avanzaes</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Compression method</source>
        <translation>Métodu de compresión</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="214"/>
        <source>Encrypt the archive</source>
        <translation>Cifrar l'archivu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="216"/>
        <source>CPU threads</source>
        <translation>hilos de CPU</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="218"/>
        <source>Encrypt the file list too</source>
        <translation>Cifrar tamién la llista de ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="220"/>
        <source>Split to volumes</source>
        <translation>Dixebrar en volúmenes</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="222"/>
        <source>Comment</source>
        <translation>Comentariu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="224"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Comprimir</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Store</source>
        <translation>Nengún</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Fastest</source>
        <translation>El más rápidu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Fast</source>
        <translation>Rápidu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Good</source>
        <translation>Bonu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Best</source>
        <translation>El meyor</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>Single thread</source>
        <translation>hilo único</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>2 threads</source>
        <translation>2 hilos</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>4 threads</source>
        <translation>4 hilos</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>8 threads</source>
        <translation>8 hilos</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support zip, 7z type only</source>
        <translation>Namás sofita zip y 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="263"/>
        <source>Support 7z type only</source>
        <translation>Namás sofita 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="275"/>
        <source>Enter up to %1 characters</source>
        <translation>Introduz hasta %1 caráuteres</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="296"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="297"/>
        <source>Save to</source>
        <translation>Guardar en</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Invalid file name</source>
        <translation>El nome nun ye válidu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="495"/>
        <source>Please enter the path</source>
        <translation>Introduz un camín</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="500"/>
        <source>The path does not exist, please retry</source>
        <translation>El camín nun esiste, volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="505"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nun tienes permisu pa guardar ficheros nesti direutoriu, cámbialu y volvi tentalu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="513"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Hai milenta volúmenes, usa un valor más baxu y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 nun esiste nel discu, compruébalo y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="528"/>
        <source>You do not have permission to compress %1</source>
        <translation>Nun tienes permisu pa comprimir %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="548"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>El ficheru orixinal de %1 nun esiste, compruébalo y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="583"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D'acuerdu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="797"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="797"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Trocar</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="705"/>
        <source>Total size: %1</source>
        <translation>Tamañu total: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="725"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>El nome ye igual que'l del archivu, usa otru</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="733"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>Les contraseñes de los ficheros ZIP nun puen tar en chinu</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="797"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Yá esiste un ficheru col mesmu nome, ¿trocalu?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="837"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Namás se sofiten los caráuteres chinos, llatinos y dalgunos símbolos</translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="296"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="309"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="314"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="317"/>
        <source>Open with</source>
        <translation>Abrir con</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="321"/>
        <source>Select default program</source>
        <translation>Otru programa</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="364"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>Esto va desaniciar permanentemente los ficheros. ¿De xuru que quies siguir?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="364"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="364"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="475"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Amestar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="473"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>¿Quies amestar l'archivu a la llista o abrilu nuna ventana nueva?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="476"/>
        <source>Open in new window</source>
        <translation>Abrir nuna ventana nueva</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="312"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>Nun se sofiten los cambeos a los archivos d'esti tipu. Convierti l'archivu pa guardar los cambeos.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="320"/>
        <source>Convert the format to:</source>
        <translation>Convertir a:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="344"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="345"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Convertir</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>elementu/os</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>La estraición falló</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>El ficheru ta dañáu y nun ye posible estrayelu</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Retentar</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Arrastra un ficheru o una carpeta hasta equí</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Esbillar ficheros</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>L'archivu ta dañáu</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>Abrir nel mou de namás llectura</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Cargando, espera…</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <source>Archive Manager</source>
        <translation>Xestor d'archivos</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>Deepin Archive Manager ye una aplicación rápida y llixera pa crear y estrayer archivos.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="179"/>
        <source>Open file</source>
        <translation>Abrir ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="180"/>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="276"/>
        <source>Create New Archive</source>
        <translation>Creación d'un archivu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="334"/>
        <source>Converting</source>
        <translation>Convirtiendo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="341"/>
        <source>Updating comments</source>
        <translation>Anovando'l comentariu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="503"/>
        <source>Plugin error</source>
        <translation>Fallu de los plugins</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1284"/>
        <source>Adding successful</source>
        <translation>L'amiestu tuvo ésitu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1316"/>
        <source>No data in it</source>
        <translation>Nun hai datos dientro</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1521"/>
        <source>Adding canceled</source>
        <translation>Encaboxóse l'amiestu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1623"/>
        <source>Adding failed</source>
        <translation>L'amiestu falló</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1676"/>
        <source>Extraction failed: the file name is too long</source>
        <translation>Falló l'extracción: nome del ficheru too llargu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1703"/>
        <source>Failed to create "%1"</source>
        <translation>Hebo un fallu al crear «%1»</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1825"/>
        <source>Open failed: the file name is too long</source>
        <translation>Falló l'apertura: nome del ficheru too llargu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2044"/>
        <source>Compression successful</source>
        <translation>La compresión tuvo ésitu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2050"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation>Nome del ficheru too llargu, polo que los primers 60 carácteres han s'interceptáu como nome del ficheru.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2079"/>
        <source>Insufficient disk space</source>
        <translation>Nun hai abondu espaciu nel discu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2109"/>
        <source>Some volumes are missing</source>
        <translation>Falten dalgunos volúmenes</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2134"/>
        <source>Wrong password, please retry</source>
        <translation>La contraseña ye incorreuta, volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2138"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation>Nome del ficheru too llargu. Por favor, mantén el nome dientro de 60 carácteres.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2159"/>
        <source>Conversion failed</source>
        <translation>Conversión fallida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2297"/>
        <source>Select file</source>
        <translation>Esbillar ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3167"/>
        <source>Enter up to %1 characters</source>
        <translation>Introduz hasta %1 caráuteres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3043"/>
        <source>File info</source>
        <translation>Información del ficheru</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1393"/>
        <source>Do you want to delete the archive?</source>
        <translation>¿Quies desaniciar l'archivu?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="533"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>%1 camudó, volvi importar el ficheru.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="75"/>
        <source>Archive Manager</source>
        <translation>Xestor d'archivos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="136"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nun tienes permisu pa guardar ficheros nel direutoriu esbilláu, cámbialu y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="299"/>
        <source>Adding files to %1</source>
        <translation>Amestando ficheros a %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="306"/>
        <source>Compressing</source>
        <translation>Comprimiendo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="313"/>
        <source>Extracting</source>
        <translation>Estrayendo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="320"/>
        <source>Deleting</source>
        <translation>Desaniciando</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="493"/>
        <source>Loading, please wait...</source>
        <translation>Cargando, espera…</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="569"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>¿De xuru que quies parar la xera en cursu?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1290"/>
        <source>Updating, please wait...</source>
        <translation>Anovando, espera…</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1698"/>
        <source>File name too long</source>
        <translation>El nome ye perllongu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2075"/>
        <source>Failed to create file</source>
        <translation>Hebo un fallu al crear el ficheru</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <source>Compression failed</source>
        <translation>La compresión falló</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2407"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Trocar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2471"/>
        <source>Find directory</source>
        <translation>Busca d'un direutoriu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <source>Open failed</source>
        <translation>L'apertura falló</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1619"/>
        <source>Wrong password</source>
        <translation>La contraseña nun ye correuta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="612"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>El xestor d'archivos nun sofita esti formatu de ficheru</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="136"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D'acuerdu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="327"/>
        <source>Renaming</source>
        <translation>Renombrando</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="441"/>
        <source>You do not have permission to load %1</source>
        <translation>Nun tienes permisu pa cargar %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="569"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="569"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="597"/>
        <source>No such file or directory</source>
        <translation>El ficheru o la carpeta nun esiste</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1332"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>La estraición tuvo ésitu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1542"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>Encaboxóse la estraición</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1688"/>
        <source>The archive is damaged</source>
        <translation>L'archivu ta dañáu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2048"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>La descompresión tuvo ésitu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2054"/>
        <source>Conversion successful</source>
        <translation>La conversión tuvo ésitu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2083"/>
        <source>The compressed volumes already exist</source>
        <translation>Los volúmenes comprimíos ya esisten</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>La descompresión falló</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2289"/>
        <source>Close</source>
        <translation>Zarrar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2293"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2301"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2309"/>
        <source>Display shortcuts</source>
        <translation>Amosar los atayos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2321"/>
        <source>Shortcuts</source>
        <translation>Atayos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2399"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>El nome ye igual que'l del archivu, usa otru</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2407"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Yá esiste otru ficheru col mesmu nome, ¿trocalu?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2550"/>
        <source>You cannot add the archive to itself</source>
        <translation>Nun pues amestar l'archivu a sigo mesmu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2565"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>Nun pues amestar ficheros a los archivos d'esti tipu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2889"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Anovar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3067"/>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3083"/>
        <source>Size</source>
        <translation>Tamañu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3084"/>
        <source>Type</source>
        <translation>Tipu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3085"/>
        <source>Location</source>
        <translation>Allugamientu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3086"/>
        <source>Time created</source>
        <translation>Data de creación</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3087"/>
        <source>Time accessed</source>
        <translation>Data d'accesu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3088"/>
        <source>Time modified</source>
        <translation>Data de modificación</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3098"/>
        <source>Archive</source>
        <translation>Archivu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3129"/>
        <source>Comment</source>
        <translation>Comentariu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="642"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Comprueba les asociaciones de ficheros nos axustes del xestor d'archivos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2278"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>L'archivu camudó, volvi importalu.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Direutoriu</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Aplicación</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Videu</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Audiu</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Imaxe</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Archivu</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>Executable</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Documentu</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Ficheru de respaldu</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>Desconozse</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Abrir con</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Amestar otros programes</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Predeterminar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Aplicaciones aconseyaes</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Otres aplicaciones</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>El ficheru ta cifráu, introduz la contraseña</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Camín actual:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Volver a: %1</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>Númberu de xeres en cursu: %1</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <source>Task</source>
        <translation>Xera</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <source>Extracting</source>
        <translation>Estrayendo</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>¿De xuru que quies parar la estraición?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="59"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Velocidá</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="59"/>
        <source>Calculating...</source>
        <translation>Calculando…</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="61"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Velocidá</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <source>Speed</source>
        <comment>rename</comment>
        <translation>Velocidá</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="65"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Velocidá</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="69"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Velocidá</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="72"/>
        <source>Time left</source>
        <translation>Tiempu que queda</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="131"/>
        <source>Compressing</source>
        <translation>Comprimiendo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="133"/>
        <source>Deleting</source>
        <translation>Desaniciando</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="135"/>
        <source>Renaming</source>
        <translation>Renombrando</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="137"/>
        <source>Converting</source>
        <translation>Convirtiendo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="139"/>
        <source>Updating the comment...</source>
        <translation>Anovando'l comentariu…</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <source>Extracting</source>
        <translation>Estrayendo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="152"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Posar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="188"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="371"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Siguir</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="404"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="393"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>¿De xuru que quies parar la descompresión?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="395"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>¿De xuru que quies parar el desaniciu?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="391"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>¿De xuru que quies parar la compresión?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="399"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>¿De xuru que quies parar la conversión?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Data de modificación</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Tipu</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Tamañu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2886"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>%1 camudó, ¿Quies guardar los cambeos nel archivu?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>Xeneral</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Estraición</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Crear automáticamennte una carpeta al estrayer múltiples ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>Amosar los ficheros estrayíos al estrayelos</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Xestión de ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>Desaniciar los ficheros darréu de comprimilos</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Asociaciones de ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Tipos de ficheros</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Saltar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Mecer</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Yá esiste otru ficheru col mesmu nome, ¿trocalu?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="215"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Trocar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="483"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="484"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D'acuerdu</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Yá esiste otra carpeta col mesmu nome, ¿trocala?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="218"/>
        <source>Apply to all</source>
        <translation>Aplicar a too</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="557"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="608"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anular</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="609"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="619"/>
        <source>The name already exists</source>
        <translation>El nome ya esiste</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <source>Current directory</source>
        <translation>Direutoriu actual</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Desmarcar too</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Marcar too</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>Marcar lo aconseyao</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Estrayer los ficheros en</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <source>Other directory</source>
        <translation>Otru direutoriu</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <source>Desktop</source>
        <translation>Escritoriu</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Desaniciar los archivos darréu d'estrayelos</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <source>Never</source>
        <translation>Enxamás</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <source>Ask for confirmation</source>
        <translation>Pidir la confirmación</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <source>Always</source>
        <translation>Siempres</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>La compresión tuvo ésitu</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3324"/>
        <source>Open file</source>
        <translation>Abrir ficheru</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3327"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3386"/>
        <source>File info</source>
        <translation>Información del ficheru</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <source>Extract to:</source>
        <translation>Estrayer en:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Estrayer</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>El camín d'estraición predetermináu nun esiste, volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="195"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nin tienes permisu pa guardar ficheros nesti direutoriu, cámbialu y volvi tentalo</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="199"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D'acuerdu</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="213"/>
        <source>Find directory</source>
        <translation>Busca d'un direutoriu</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="401"/>
        <source>You cannot add the archive to itself</source>
        <translation>Nun pues amestar l'archivu a sigo mesmu</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="401"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D'acuerdu</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="627"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Estrayer</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="629"/>
        <source>Extract to current directory</source>
        <translation>Estrayer nel direutoriu actual</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="631"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="633"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="638"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="645"/>
        <source>Open with</source>
        <translation>Abrir con</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="649"/>
        <source>Select default program</source>
        <translation>Otru programa</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="700"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="700"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="700"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>¿Quies desaniciar los ficheros esbillaos?</translation>
    </message>
</context>
</TS>
